BEGIN TRANSACTION;
CREATE TABLE IF NOT EXISTS "configs" (
	"id"	integer NOT NULL,
	"key"	varchar NOT NULL,
	"value"	varchar,
	"cat"	varchar NOT NULL DEFAULT 'Config',
	"description"	varchar NOT NULL DEFAULT '',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "shares" (
	"id"	integer NOT NULL,
	"owner"	varchar,
	"downloadable"	tinyint(1) NOT NULL DEFAULT '0',
	"password"	varchar,
	"public"	tinyint(1) NOT NULL DEFAULT '0',
	"days"	integer NOT NULL DEFAULT '0',
	"type"	integer NOT NULL DEFAULT '0',
	"shareid"	varchar NOT NULL DEFAULT '',
	"parent_id"	integer,
	"url"	varchar NOT NULL DEFAULT '',
	"name"	varchar NOT NULL DEFAULT '',
	"expirestamp"	datetime,
	"created_at"	datetime,
	"updated_at"	datetime,
	"pre_create"	integer NOT NULL DEFAULT '0',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "relationships" (
	"id"	integer NOT NULL,
	"name"	varchar NOT NULL DEFAULT '',
	"created_at"	datetime,
	"updated_at"	datetime,
	"customflag"	integer NOT NULL DEFAULT '1',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "person_album_photo" (
	"id"	integer NOT NULL,
	"cluster_id"	integer DEFAULT '0',
	"face_id"	integer DEFAULT '0',
	"file_path"	text NOT NULL DEFAULT '',
	"created_at"	datetime,
	"owner"	varchar,
	"relationship_id" INTEGER,
	"title"           VARCHAR       NOT NULL DEFAULT '',
	"coverpicid"      INTEGER       NOT NULL DEFAULT '0',
    "coverpicpath"    VARCHAR       NOT NULL DEFAULT '',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "share_album_photo" (
	"id"	integer NOT NULL,
	"share_id"	integer DEFAULT '0',
	"album_id"	integer DEFAULT '0',
	"file_path"	text NOT NULL DEFAULT '',
	"created_at"	datetime,
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "directory" (
	"id"	integer NOT NULL,
	"title"	varchar,
	"parent_id"	integer,
	"description"	text ,
	"created_at"	datetime,
	"updated_at"	datetime,
	"deleted_at"	datetime,
	"node_type"	integer NOT NULL DEFAULT '4',
	"isactivedeletion"	text NOT NULL DEFAULT '0',
	"predelete"	tinyint(1) NOT NULL DEFAULT '0',
	"display"	integer NOT NULL DEFAULT '1',
	"absolutepath"	text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"owner"	varchar,
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "tasks" (
	"id"	integer NOT NULL,
	"url"	text,
	"platform"	varchar,
	"album_id"	text,
	"album_name"	text,
	"directory_id"	integer,
	"is_directory"	integer NOT NULL DEFAULT '0',
	"event"	varchar,
	"priority"	integer NOT NULL DEFAULT '0',
	"created_at"	integer,
	"deleted_at"	integer,
	"owner"	varchar,
	"updated_at"	integer,
	"owner_id"	integer NOT NULL DEFAULT '0',
	"watch_directory"	text,
	"event_time"	integer NOT NULL DEFAULT '0',
	"externaldirectoryid"	integer NOT NULL DEFAULT '0',
	PRIMARY KEY("id" AUTOINCREMENT)
);

CREATE TABLE IF NOT EXISTS "file_tasks" (
	"id"	integer NOT NULL,
	"target_url"	text,
	"relative_target_url"	text,
	"home_path"	text,
	"directory_ids"	text,
	"directory_pid"	integer,
	"photo_ids"	text,
	"album_id"	integer,
	"owner_id"	integer,
	"owner"	varchar,
	"upload_setting"	varchar,
	"event"	varchar,
	"created_at"	datetime,
	"updated_at"	datetime,
	"deleted_at"	datetime,
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "albums_photos" (
	"id"	integer NOT NULL,
	"photo_id"	integer,
	"album_id"	integer,
	"file_path"	text NOT NULL,
	"checksum"	varchar NOT NULL DEFAULT '',
	"owner"	varchar,
	"created_at"	datetime,
	"updated_at"	datetime,
	"deleted_at"	datetime,
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "albums" (
	"id"	INTEGER NOT NULL,
	"title"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"parent_id"	INTEGER DEFAULT NULL,
	"description"	CLOB NOT NULL COLLATE BINARY,
	"min_takestamp"	DATETIME DEFAULT NULL,
	"max_takestamp"	DATETIME DEFAULT NULL,
	"public"	BOOLEAN NOT NULL DEFAULT '0',
	"full_photo"	BOOLEAN NOT NULL DEFAULT '1',
	"visible_hidden"	BOOLEAN NOT NULL DEFAULT '1',
	"downloadable"	BOOLEAN NOT NULL DEFAULT '0',
	"password"	VARCHAR(255) DEFAULT NULL COLLATE BINARY,
	"license"	VARCHAR(255) NOT NULL DEFAULT 'none' COLLATE BINARY,
	"created_at"	DATETIME DEFAULT NULL,
	"updated_at"	DATETIME DEFAULT NULL,
	"deleted_at"	DATETIME DEFAULT NULL,
	"share_button_visible"	BOOLEAN NOT NULL DEFAULT '0',
	"smart"	BOOLEAN NOT NULL DEFAULT '0',
	"showtags"	CLOB DEFAULT NULL COLLATE BINARY,
	"sharepublic"	INTEGER NOT NULL DEFAULT 1,
	"days"	INTEGER NOT NULL DEFAULT 0,
	"coverpicid"	integer NOT NULL DEFAULT '0',
	"coverpicpath"	varchar NOT NULL DEFAULT '',
	"owner"	VARCHAR(255),
	"albumid"	VARCHAR(255),
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "photos" (
	"id"	INTEGER NOT NULL,
	"title"	VARCHAR(255) NOT NULL COLLATE BINARY,
	"description"	CLOB DEFAULT NULL COLLATE BINARY,

	"width"	INTEGER DEFAULT NULL,
	"height"	INTEGER DEFAULT NULL,
	"iso"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"aperture"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"make"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"model"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"lens"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"shutter"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"focal"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"latitude"	NUMERIC(10, 0) DEFAULT NULL,
	"longitude"	NUMERIC(10, 0) DEFAULT NULL,
	"altitude"	NUMERIC(10, 0) DEFAULT NULL,
	"takestamp"	DATETIME DEFAULT NULL,
	"star"	BOOLEAN NOT NULL DEFAULT '0',
	"thumbUrl"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"checksum"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"license"	VARCHAR(255) NOT NULL DEFAULT 'none' COLLATE BINARY,
	"created_at"	DATETIME DEFAULT NULL,
	"updated_at"	DATETIME DEFAULT NULL,
	"medium"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"medium2x"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"small"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"small2x"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"deleted_at"	DATETIME DEFAULT NULL,
	"thumb2x"	BOOLEAN NOT NULL DEFAULT '0',
	"imgDirection"	NUMERIC(10, 0) DEFAULT NULL,
	"livePhotoUrl"	VARCHAR(255) DEFAULT NULL COLLATE BINARY,
	"livePhotoContentID"	VARCHAR(255) DEFAULT NULL COLLATE BINARY,
	"livePhotoChecksum"	VARCHAR(255) DEFAULT NULL COLLATE BINARY,
	"type"	VARCHAR(30) NOT NULL DEFAULT '' COLLATE BINARY,
	"shootime"	DATETIME DEFAULT NULL,
	"ordertime"	DATETIME DEFAULT NULL,
	"owner"	VARCHAR(255) DEFAULT NULL COLLATE BINARY,
	"directory_id"	INTEGER DEFAULT NULL,
	"node_type"	INTEGER NOT NULL DEFAULT 1,
	"isactivedeletion"	CLOB NOT NULL DEFAULT '0' COLLATE BINARY,
	"duration"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"predelete"	BOOLEAN NOT NULL DEFAULT '0',
	"old_title"	VARCHAR(255) NOT NULL DEFAULT '' COLLATE BINARY,
	"display"	INTEGER NOT NULL DEFAULT 1,
	"size"	BIGINT NOT NULL DEFAULT 0,
	"absolutepath"	text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"livephotomatchid"	text NOT NULL DEFAULT '',
	"matchphotoid"	text NOT NULL DEFAULT '',
	"country"   TEXT    NOT NULL DEFAULT '',
    "province"  TEXT    NOT NULL DEFAULT '',
    "city"      TEXT    NOT NULL DEFAULT '',
    "district"  TEXT    NOT NULL DEFAULT '',
    "address"   TEXT    NOT NULL DEFAULT '',
    "street"    TEXT    NOT NULL DEFAULT '',
    "snumber"   TEXT    NOT NULL DEFAULT '',
    "landmark"  TEXT    NOT NULL DEFAULT '',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "external_directory" (
	"id"	integer NOT NULL,
	"path"	text NOT NULL,
	"owner"	varchar NOT NULL DEFAULT '',
	"linkname"	varchar NOT NULL DEFAULT '',
	"path_type"	integer NOT NULL DEFAULT '1',
	"created_at"	datetime,
	"updated_at"	datetime,
	"deleted_at"	datetime,
	"prehomepath"	text NOT NULL DEFAULT '',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS "collects" (
	"id" integer NOT NULL , 
	"file_path"   TEXT  , 
	"owner" varchar NOT NULL DEFAULT '', 
	"created_at" datetime, 
	"updated_at" datetime, 
	"deleted_at" datetime,
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS albums_insideshares (
    id           INTEGER,
    album_id     INTEGER,                    
    owner        VARCHAR,
    authority    INTEGER,                       
    created_at       DATETIME DEFAULT NULL,
	updated_at       DATETIME DEFAULT NULL,
    deleted_at       DATETIME DEFAULT NULL,
    PRIMARY KEY (
        id AUTOINCREMENT
    )
);
CREATE TABLE IF NOT EXISTS albums_directorys (
    id           INTEGER,                   
    owner        VARCHAR,
	album_id     INTEGER, 
    monitorpath  text,                       
    created_at       DATETIME DEFAULT NULL,
	updated_at       DATETIME DEFAULT NULL,
    deleted_at       DATETIME DEFAULT NULL,
	UNIQUE (owner, album_id, monitorpath),
    PRIMARY KEY (
        id AUTOINCREMENT
    )
	
);
CREATE TABLE IF NOT EXISTS "person_faces" (
    "id"          INTEGER NOT NULL,
    "file_path"   TEXT    ,
	"embedding"       TEXT,
	"facial_area"       TEXT,
	"iscluster"	integer DEFAULT '0',
	PRIMARY KEY("id" AUTOINCREMENT)
);
CREATE TABLE IF NOT EXISTS scene (
    AFP_No        INTEGER,
    FIL_Md5       TEXT    NOT NULL
                          DEFAULT '',
    FIL_FilePath  TEXT    NOT NULL
                          DEFAULT '',
    FIL_Owner     TEXT    NOT NULL
                          DEFAULT '',
    OVN_Label     INTEGER NOT NULL
                          DEFAULT 0,
    OVN_Accuracy  REAL    NOT NULL
                          DEFAULT 0,
    FIL_Delete    INTEGER DEFAULT 0,
    PRIMARY KEY (
        AFP_No AUTOINCREMENT
    )
);

CREATE TABLE IF NOT EXISTS "face_tasks" (
	"id"	integer NOT NULL,
	"url"	text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"owner"     text NOT NULL,
	"checksum"     text,
	PRIMARY KEY("id" AUTOINCREMENT)
);

CREATE TABLE IF NOT EXISTS "thumb_tasks" (
	"id"	integer NOT NULL,
	"url"     text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"node_type"	integer ,
	"type"	VARCHAR(30),
	"width"	integer ,
	"height"	integer ,
	"checksum"     text,
	PRIMARY KEY("id" AUTOINCREMENT)
);

CREATE TABLE IF NOT EXISTS "address_tasks" (
	"id"	integer NOT NULL,
	"url"     text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"owner"     text NOT NULL,
	"latitude"           NUMERIC (10, 0) DEFAULT NULL,
	"longitude"          NUMERIC (10, 0) DEFAULT NULL,
	"checksum"     text,
	PRIMARY KEY("id" AUTOINCREMENT)
);

CREATE TABLE IF NOT EXISTS "scene_tasks" (
	"id"	integer NOT NULL,
	"url"     text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"owner"     text,
	"checksum"     text,
	PRIMARY KEY("id" AUTOINCREMENT)
);

CREATE TABLE IF NOT EXISTS "ocr_tasks" (
	"id"	integer NOT NULL,
	"url"     text NOT NULL UNIQUE ON CONFLICT IGNORE,
	"owner"     text,
	"checksum"     text,
	PRIMARY KEY("id" AUTOINCREMENT)
);

CREATE TABLE IF NOT EXISTS "photo_ocrcontents" (
	"file_path"	text NOT NULL,
	"content"	text NOT NULL
);

CREATE TABLE IF NOT EXISTS "photo_tags" (
	"file_path"	text NOT NULL,
	"tag"	text NOT NULL
);


INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (1,'自己',NULL,NULL,1);
INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (2,'父母',NULL,NULL,1);
INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (3,'朋友',NULL,NULL,1);
INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (4,'伴侣',NULL,NULL,1);
INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (5,'孩子',NULL,NULL,1);
INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (6,'同事',NULL,NULL,1);
INSERT OR IGNORE INTO "relationships" ("id","name","created_at","updated_at","customflag") VALUES (7,'其他',NULL,NULL,1);

CREATE INDEX IF NOT EXISTS "person_album_photo_album_id_index" ON "person_album_photo" (
	"album_id"
);
CREATE INDEX IF NOT EXISTS "person_album_photo_photo_id_index" ON "person_album_photo" (
	"photo_id"
);
CREATE UNIQUE INDEX IF NOT EXISTS "file_tasks_id_unique" ON "file_tasks" (
	"id"
);
CREATE INDEX IF NOT EXISTS "albums_photos_id_index" ON "albums_photos" (
	"id"
);
CREATE INDEX IF NOT EXISTS "albums_photos_photo_id_index" ON "albums_photos" (
	"photo_id"
);
CREATE INDEX IF NOT EXISTS "albums_photos_album_id_index" ON "albums_photos" (
	"album_id"
);
CREATE INDEX IF NOT EXISTS "albums_parent_id_index" ON "albums" (
	"parent_id"
);
CREATE INDEX IF NOT EXISTS "photos_directory_id_index" ON "photos" (
	"directory_id"
);
CREATE INDEX IF NOT EXISTS "external_directory_id_index" ON "external_directory" (
	"id"
);
CREATE INDEX IF NOT EXISTS "photos_ordertime_index" ON "photos" (
	"ordertime"
);
CREATE INDEX IF NOT EXISTS "add_photos_title_index" ON "photos" (
	"title"
);
CREATE INDEX IF NOT EXISTS "add_photos_node_type_index" ON "photos" (
	"node_type"
);
CREATE INDEX IF NOT EXISTS "add_photos_size_index" ON "photos" (
	"size"
);
CREATE INDEX IF NOT EXISTS "add_photos_absolutepath_index" ON "photos" (
	"absolutepath"
);
CREATE INDEX IF NOT EXISTS "add_directory_created_at_index" ON "directory" (
	"created_at"
);
CREATE INDEX IF NOT EXISTS "add_directory_title_index" ON "directory" (
	"title"
);
CREATE INDEX IF NOT EXISTS "add_directory_absolutepath_index" ON "directory" (
	"absolutepath"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_piccountry" ON "scene" (
    "PIC_Country"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_picprovince" ON "scene" (
    "PIC_Province"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_piccity" ON "scene" (
    "PIC_City"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_picdistrict" ON "scene" (
    "PIC_District"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_picstreet" ON "scene" (
    "PIC_Street"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_picaddress" ON "scene" (
    "PIC_Address"
);
CREATE INDEX IF NOT EXISTS "absolutefilepathtotal_index_ovnlabel" ON "scene" (
    "OVN_Label"
);
CREATE UNIQUE INDEX IF NOT EXISTS "add_collect_unique_index" ON "collects" (
    "file_path",
    "owner"
);
CREATE INDEX IF NOT EXISTS "photo_ocrcontents_index_file_path" ON "photo_ocrcontents" (
    "file_path"
);
CREATE INDEX IF NOT EXISTS "photo_ocrcontents_index_content" ON "photo_ocrcontents" (
    "content"
);
CREATE INDEX IF NOT EXISTS "photo_tags_index_file_path" ON "photo_tags" (
    "file_path"
);
CREATE INDEX IF NOT EXISTS "photo_tags_index_tag" ON "photo_tags" (
    "tag"
);

CREATE INDEX IF NOT EXISTS "person_album_photo_index_cluster_id" ON "person_album_photo" (
    "cluster_id"
);
CREATE INDEX IF NOT EXISTS "person_faces_index_file_path" ON "person_faces" (
    "file_path"
);
CREATE UNIQUE INDEX IF NOT EXISTS "add_person_album_photo_unique_index" ON "person_album_photo" (
    "file_path",
    "owner",
	"cluster_id"
);

CREATE UNIQUE INDEX IF NOT EXISTS "add_scene_unique_index" ON "scene" (
    "FIL_FilePath",
    "FIL_Owner",
	"OVN_Label"
);



COMMIT;
